def add(i, y):
    print(str(i) + " + " + str(y) + " = " + str((i + y)))


def sub(i, y):
    print(str(i) + " - " + str(y) + " = " + str((i - y)))


def mul(i, y):
    print(str(i) + " * " + str(y) + " = " + str((i * y)))


def div(i, y):
    print(str(i) + " / " + str(y) + " = " + str((i / y)))

